package Hyper::Developer;

use strict;
use warnings;
use version; our $VERSION = qv('0.06');

1;

__END__

=pod

=head1 NAME

Hyper::Developer - Hyper Developer Tools

=head1 VERSION

This document describes Hyper::Developer 0.06

=head1 SYNOPSIS

    use Hyper::Developer 0.06;

=head1 DESCRIPTION

The Hyper::Developer namespace contains the Developer Tools
for working with Hyper.

=head1 SUBROUTINES/METHODS

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item *

version

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 RCS INFORMATIONS

=over

=item Last changed by

 $Author: ac0v $

=item Id

 $Id: Developer.pm 329 2008-02-18 13:13:53Z ac0v $

=item Revision

 $Revision: 329 $

=item Date

 $Date: 2008-02-18 14:13:53 +0100 (Mo, 18 Feb 2008) $

=item HeadURL

 $HeadURL: http://svn.hyper-framework.org/Hyper/Hyper-Developer/branches/0.06/lib/Hyper/Developer.pm $

=back

=head1 AUTHOR

Andreas Specht  C<< <ACID@cpan.org> >>

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2007, Andreas Specht C<< <ACID@cpan.org> >>.
All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut
